use yew::prelude::*;
use yew_router::prelude::*;

use components::*;
use pages::*;

mod components;
mod pages;

#[derive(Clone, Routable, PartialEq)]
pub enum Route {
    #[at("/")]
    Home,
    #[at("/participants")]
    Participants,
    #[at("/participants/add")]
    AddParticipants,
    #[at("/times")]
    Times,
    #[at("/times/add")]
    AddTimes,
}

fn switch(route: Route) -> Html {
    match route {
        Route::Home => html! { <Home /> },
        Route::Participants => html! { <Participants /> },
        Route::AddParticipants => html! { <participants::AddParticipant /> },
        Route::Times => html! { <Times /> },
        Route::AddTimes => html! { <times::AddTime /> },
    }
}

#[function_component(App)]
fn app() -> Html {
    html! {
        <BrowserRouter>
            <Navbar />
            <main>
                <Switch<Route> render={switch} /> // <- must be child of <BrowserRouter>
            </main>
            <Footer />
        </BrowserRouter>
    }
}

fn main() {
    yew::Renderer::<App>::new().render();
}
